## 0.0.25

This new version includes improvements to the basecallbackmanager and the pinned version of langchain.

### New Features

- The basecallbackmanager now requires an explicit handlers argument, enhancing clarity and reducing potential for errors (169f72) (Eric Ma)

### Bug Fixes

- No bug fixes in this release.

### Deprecations

- The version of langchain used in the project has been pinned, ensuring stability and compatibility with this version of the software (631c29) (Eric Ma)
